Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Database Migration Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for AWS Database Migration Service - AWS Identity and Access Management

# Actions, resources, and condition keys for AWS Database Migration Service

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html .

AWS Database Migration Service (service prefix: `dms` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Database Migration Service
- Resource types defined by AWS Database Migration Service
- Condition keys for AWS Database Migration Service

## Actions defined by AWS Database Migration Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTagsToResource | Adds metadata tags to a DMS resource, including replication instance, endpoint, security group, and migration task | Tagging | Certificate |  |
Endpoint |  |
EventSubscription |  |
ReplicationInstance |  |
ReplicationSubnetGroup |  |
ReplicationTask |  |
| aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
ApplyPendingMaintenanceAction | Applies a pending maintenance action to a resource (for example, to a replication instance). | Write | ReplicationInstance* |  |
CreateEndpoint | Creates an endpoint using the provided settings | Write |  | aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
CreateEventSubscription | Creates an AWS DMS event notification subscription. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
CreateReplicationInstance | Creates the replication instance using the specified parameters | Write |  | aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
CreateReplicationSubnetGroup | Creates a replication subnet group given a list of the subnet IDs in a VPC | Write |  | aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
CreateReplicationTask | Creates a replication task using the specified parameters | Write | Endpoint* |  |
ReplicationInstance* |  |
| aws:RequestTag/${TagKey} aws:TagKeys dms:req-tag/${TagKey} |
DeleteCertificate | Deletes the specified certificate | Write | Certificate* |  |
DeleteEndpoint | Deletes the specified endpoint | Write | Endpoint* |  |
DeleteEventSubscription | Deletes an AWS DMS event subscription. | Write | EventSubscription* |  |
DeleteReplicationInstance | Deletes the specified replication instance | Write | ReplicationInstance* |  |
DeleteReplicationSubnetGroup | Deletes a subnet group | Write | ReplicationSubnetGroup* |  |
DeleteReplicationTask | Deletes the specified replication task | Write | ReplicationTask* |  |
DescribeAccountAttributes | Lists all of the AWS DMS attributes for a customer account | Read |  |  |
DescribeCertificates | Provides a description of the certificate. | Read |  |  |
DescribeConnections | Describes the status of the connections that have been made between the replication instance and an endpoint | Read |  |  |
DescribeEndpointTypes | Returns information about the type of endpoints available | Read |  |  |
DescribeEndpoints | Returns information about the endpoints for your account in the current region | Read |  |  |
DescribeEventCategories | Lists categories for all event source types, or, if specified, for a specified source type. | Read |  |  |
DescribeEventSubscriptions | Lists all the event subscriptions for a customer account. | Read |  |  |
DescribeEvents | Lists events for a given source identifier and source type. | Read |  |  |
DescribeOrderableReplicationInstances | Returns information about the replication instance types that can be created in the specified region | Read |  |  |
DescribeRefreshSchemasStatus | Returns the status of the RefreshSchemas operation | Read | Endpoint* |  |
DescribeReplicationInstanceTaskLogs | Returns information about the task logs for the specified task. | Read | ReplicationInstance* |  |
| aws:ResourceTag/${TagKey} aws:TagKeys |
DescribeReplicationInstances | Returns information about replication instances for your account in the current region | Read |  |  |
DescribeReplicationSubnetGroups | Returns information about the replication subnet groups | Read |  |  |
DescribeReplicationTaskAssessmentResults | Returns the task assessment results from Amazon S3. This action always returns the latest results. | Read | ReplicationTask |  |
DescribeReplicationTasks | Returns information about replication tasks for your account in the current region | Read |  |  |
DescribeSchemas | Returns information about the schema for the specified endpoint | Read | Endpoint* |  |
DescribeTableStatistics | Returns table statistics on the database migration task, including table name, rows inserted, rows updated, and rows deleted | Read | ReplicationTask* |  |
ImportCertificate | Uploads the specified certificate. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
ListTagsForResource | Lists all tags for an AWS DMS resource | List | Certificate |  |
Endpoint |  |
EventSubscription |  |
ReplicationInstance |  |
ReplicationSubnetGroup |  |
ReplicationTask |  |
ModifyEndpoint | Modifies the specified endpoint | Write | Endpoint* |  |
Certificate |  |
ModifyEventSubscription | Modifies an existing AWS DMS event notification subscription. | Write |  |  |
ModifyReplicationInstance | Modifies the replication instance to apply new settings | Write | ReplicationInstance* |  |
ModifyReplicationSubnetGroup | Modifies the settings for the specified replication subnet group | Write |  |  |
ModifyReplicationTask | Modifies the specified replication task. | Write | ReplicationTask* |  |
RebootReplicationInstance | Reboots a replication instance. Rebooting results in a momentary outage, until the replication instance becomes available again. | Write | ReplicationInstance* |  |
RefreshSchemas | Populates the schema for the specified endpoint | Write | Endpoint* |  |
ReplicationInstance* |  |
ReloadTables | Reloads the target database table with the source data. | Write | ReplicationTask* |  |
RemoveTagsFromResource | Removes metadata tags from a DMS resource | Tagging | Certificate |  |
Endpoint |  |
EventSubscription |  |
ReplicationInstance |  |
ReplicationSubnetGroup |  |
ReplicationTask |  |
| aws:TagKeys |
StartReplicationTask | Starts the replication task | Write | ReplicationTask* |  |
StartReplicationTaskAssessment | Starts the replication task assessment for unsupported data types in the source database. | Write | ReplicationTask* |  |
StopReplicationTask | Stops the replication task | Write | ReplicationTask* |  |
TestConnection | Tests the connection between the replication instance and the endpoint | Read | Endpoint* |  |
ReplicationInstance* |  |

## Resource types defined by AWS Database Migration Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
ReplicationInstance | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:rep:*` | aws:ResourceTag/${TagKey} dms:rep-tag/${TagKey}
ReplicationTask | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:task:*` | aws:ResourceTag/${TagKey} dms:task-tag/${TagKey}
Endpoint | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:endpoint:*` | aws:ResourceTag/${TagKey} dms:endpoint-tag/${TagKey}
Certificate | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:cert:*` | aws:ResourceTag/${TagKey} dms:cert-tag/${TagKey}
EventSubscription | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:es:*` | aws:ResourceTag/${TagKey} dms:es-tag/${TagKey}
ReplicationSubnetGroup | `arn:$ { Partition}:dms:$ { Region}:$ { Account}:subgrp:*` | aws:ResourceTag/${TagKey} dms:subgrp-tag/${TagKey}

## Condition keys for AWS Database Migration Service

AWS Database Migration Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String
dms:cert-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for Certificate | String
dms:endpoint-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for Endpoint | String
dms:es-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for EventSubscription | String
dms:rep-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for ReplicationInstance | String
dms:req-tag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
dms:subgrp-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for ReplicationSubnetGroup | String
dms:task-tag/${TagKey} | Filters actions based on the presence of tag keys in the request for ReplicationTask | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.